AssetsPaths class

Constructors

AssetsPaths()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

animations → const String
assets → const String
audios → const String
documents → const String
fonts → const String
icons → const String
images → const String
lotties → const String
models → const String
raw → const String
svgs → const String
textures → const String
videos → const String